@@ -27,60 +27,59 @@ import shutil
 import sys
 import types
 
-import jinja2
 from jinja2 import ChoiceLoader, Environment, FileSystemLoader, PrefixLoader
 from jinja2.exceptions import TemplateNotFound
 
 from . import signals
 from .utils import url_from_path
 
-THEMES_PATH = os.path.normpath(os.path.join(
-    os.path.abspath(os.path.dirname(__file__)), 'themes'))
+THEMES_PATH = os.path.normpath(
+    os.path.join(os.path.abspath(os.path.dirname(__file__)), "themes")
+)
 
 
 class AbstractWriter:
     template_file = None
 
-    def __init__(self, settings, index_title=''):
+    def __init__(self, settings, index_title=""):
         self.settings = settings
-        self.output_dir = settings['destination']
-        self.theme = settings['theme']
+        self.output_dir = settings["destination"]
+        self.theme = settings["theme"]
         self.index_title = index_title
         self.logger = logging.getLogger(__name__)
 
         # search the theme in sigal/theme if the given one does not exists
-        if not os.path.exists(self.theme) or \
-                not os.path.exists(os.path.join(self.theme, 'templates')):
+        if not os.path.exists(self.theme) or not os.path.exists(
+            os.path.join(self.theme, "templates")
+        ):
             self.theme = os.path.join(THEMES_PATH, self.theme)
             if not os.path.exists(self.theme):
                 raise Exception("Impossible to find the theme %s" % self.theme)
 
         self.logger.info("Theme  : %s", self.theme)
-        theme_relpath = os.path.join(self.theme, 'templates')
-        default_loader = FileSystemLoader(os.path.join(THEMES_PATH, 'default',
-                                                       'templates'))
-
-        # setup jinja env
-        env_options = {'trim_blocks': True, 'autoescape': True}
-        try:
-            if tuple(int(x) for x in jinja2.__version__.split('.')) >= (2, 7):
-                env_options['lstrip_blocks'] = True
-        except ValueError:
-            pass
-
-        env = Environment(
-            loader=ChoiceLoader([
-                FileSystemLoader(theme_relpath),
-                default_loader,  # implicit inheritance
-                PrefixLoader({'!default': default_loader})  # explicit one
-            ]),
-            **env_options
+        theme_relpath = os.path.join(self.theme, "templates")
+        default_loader = FileSystemLoader(
+            os.path.join(THEMES_PATH, "default", "templates")
         )
 
+        # setup jinja env
+        env_options = {"trim_blocks": True, "autoescape": True, "lstrip_blocks": True}
+
+        loaders = [
+            FileSystemLoader(theme_relpath),
+            default_loader,  # implicit inheritance
+            PrefixLoader({"!default": default_loader}),  # explicit one
+        ]
+        env = Environment(loader=ChoiceLoader(loaders), **env_options)
+
         # handle optional filters.py
-        filters_py = os.path.join(self.theme, 'filters.py')
+        filters_py = os.path.join(self.theme, "filters.py")
         if os.path.exists(filters_py):
-            mod = importlib.import_module(filters_py)
+            self.logger.info('Loading filters file: %s', filters_py)
+            module_spec = importlib.util.spec_from_file_location('filters', filters_py)
+            mod = importlib.util.module_from_spec(module_spec)
+            sys.modules['filters'] = mod
+            module_spec.loader.exec_module(mod)
             for name in dir(mod):
                 if isinstance(getattr(mod, name), types.FunctionType):
                     env.filters[name] = getattr(mod, name)
@@ -89,40 +88,49 @@ class AbstractWriter:
             self.template = env.get_template(self.template_file)
         except TemplateNotFound:
             self.logger.error(
-                'The template %s was not found in template folder %s.',
-                self.template_file, theme_relpath)
+                "The template %s was not found in template folder %s.",
+                self.template_file,
+                theme_relpath,
+            )
             sys.exit(1)
 
         # Copy the theme files in the output dir
-        self.theme_path = os.path.join(self.output_dir, 'static')
+        self.theme_path = os.path.join(self.output_dir, "static")
         if os.path.isdir(self.theme_path):
             shutil.rmtree(self.theme_path)
-        # FIXME: use dirs_exist_ok when minimum Python is 3.8
-        shutil.copytree(os.path.join(self.theme, 'static'), self.theme_path)
 
-        if self.settings['user_css']:
-            if not os.path.exists(self.settings['user_css']):
-                self.logger.error('CSS file %s could not be found',
-                                  self.settings['user_css'])
+        for static_path in (
+            os.path.join(THEMES_PATH, 'default', 'static'),
+            os.path.join(self.theme, 'static'),
+        ):
+            shutil.copytree(static_path, self.theme_path, dirs_exist_ok=True)
+
+        if self.settings["user_css"]:
+            if not os.path.exists(self.settings["user_css"]):
+                self.logger.error(
+                    "CSS file %s could not be found", self.settings["user_css"]
+                )
             else:
-                shutil.copy(self.settings['user_css'], self.theme_path)
+                shutil.copy(self.settings["user_css"], self.theme_path)
 
     def generate_context(self, album):
         """Generate the context dict for the given path."""
 
         from . import __url__ as sigal_link
+
         self.logger.info("Output album : %r", album)
         ctx = {
-            'album': album,
-            'index_title': self.index_title,
-            'settings': self.settings,
-            'sigal_link': sigal_link,
-            'theme': {'name': os.path.basename(self.theme),
-                      'url': url_from_path(os.path.relpath(self.theme_path,
-                                                           album.dst_path))},
+            "album": album,
+            "index_title": self.index_title,
+            "settings": self.settings,
+            "sigal_link": sigal_link,
+            "theme": {
+                "name": os.path.basename(self.theme),
+                "url": url_from_path(os.path.relpath(self.theme_path, album.dst_path)),
+            },
         }
-        if self.settings['user_css']:
-            ctx['user_css'] = os.path.basename(self.settings['user_css'])
+        if self.settings["user_css"]:
+            ctx["user_css"] = os.path.basename(self.settings["user_css"])
         return ctx
 
     def write(self, album):
@@ -132,15 +140,17 @@ class AbstractWriter:
         page = self.template.render(**context)
         output_file = os.path.join(album.dst_path, album.output_file)
 
-        with open(output_file, 'w', encoding='utf-8') as f:
+        with open(output_file, "w", encoding="utf-8") as f:
             f.write(page)
 
 
 class AlbumListPageWriter(AbstractWriter):
     """Generate an html page for a directory of albums"""
+
     template_file = "album_list.html"
 
 
 class AlbumPageWriter(AbstractWriter):
     """Generate html pages for a directory of images."""
+
     template_file = "album.html"
